@@ -4,10 +4,12 @@ test_that("Can retrieve version from theme object", {
     version_default()
   )
   expect_equal(
-    theme_version(bs_theme(version = "3")), "3"
+    theme_version(bs_theme(version = "3")),
+    "3"
   )
   expect_identical(
-    theme_version(bs_theme(version = "4")), "4"
+    theme_version(bs_theme(version = "4")),
+    "4"
   )
   deps <- bs_theme_dependencies(bs_theme(version = 4))
   # jQuery, Bootstrap, and bs3compat layer
